<?php

namespace SuperRhino\Utils\SubTable;

use SuperRhino\Utils\Cache;

trait DateSubTableTrait {

    public static function getSubtableKeyColumn(): string {
        return 'created_at';
    }

    /**
     * 子表表名
     * @param int $time
     * @return string
     */
    public static function subTableName(int $time): string {
        return static::subTableNameBySuffix(static::getSubTableSuffix($time));
    }

    /**
     * 子表表名 指定后缀
     * @param string $suffix 后缀
     * @return string
     */
    public static function subTableNameBySuffix(string $suffix): string {
        return (new static)->getTable() . '_' . $suffix;
    }

    /**
     * 子表字符串后缀
     * @param int $time
     * @return string
     */
    public static function getSubTableSuffix(int $time): string {
        return date('Y_m', $time);
    }

    /**
     * 下一张表时间
     * @param int $time
     * @return int
     */
    public static function getNextSubTableDateTime(int $time): int {
        return strtotime(date('Y-m-01', strtotime('+1 month', $time)));
    }

    /**
     * 检查子表是否存在
     * @param int $time
     * @return bool
     */
    public static function checkSubTableExists(int $time): bool {
        $table = static::subTableName($time);
        return Cache::getCallback('sub_table_exists:' . $table, function () use ($time, $table) {
            if (static::createSubTable($table)) {
                return true;
            }
            return null;
        }, 60 * 60 * 24 * 30);
    }

}